@@ -89,6 +89,44 @@ class _ContractBase:
         sig = calldata[:10].lower()
         return self.selectors.get(sig)
 
+    def decode_input(self, calldata: Union[str, bytes]) -> Tuple[str, Any]:
+        """
+        Decode input calldata for this contract.
+
+        Arguments
+        ---------
+        calldata : str | bytes
+            Calldata for a call to this contract
+
+        Returns
+        -------
+        str
+            Signature of the function that was called
+        Any
+            Decoded input arguments
+        """
+        if not isinstance(calldata, HexBytes):
+            calldata = HexBytes(calldata)
+
+        abi = next(
+            (
+                i
+                for i in self.abi
+                if i["type"] == "function" and build_function_selector(i) == calldata[:4].hex()
+            ),
+            None,
+        )
+        if abi is None:
+            raise ValueError("Four byte selector does not match the ABI for this contract")
+
+        function_sig = build_function_signature(abi)
+
+        types_list = get_type_strings(abi["inputs"])
+        result = eth_abi.decode_abi(types_list, calldata[4:])
+        input_args = format_input(abi, result)
+
+        return function_sig, input_args
+
 
 class ContractContainer(_ContractBase):
 
@@ -340,6 +378,44 @@ class InterfaceConstructor:
     def __repr__(self) -> str:
         return f"<{type(self).__name__} '{self._name}'>"
 
+    def decode_input(self, calldata: Union[str, bytes]) -> Tuple[str, Any]:
+        """
+        Decode input calldata for this contract.
+
+        Arguments
+        ---------
+        calldata : str | bytes
+            Calldata for a call to this contract
+
+        Returns
+        -------
+        str
+            Signature of the function that was called
+        Any
+            Decoded input arguments
+        """
+        if not isinstance(calldata, HexBytes):
+            calldata = HexBytes(calldata)
+
+        abi = next(
+            (
+                i
+                for i in self.abi
+                if i["type"] == "function" and build_function_selector(i) == calldata[:4].hex()
+            ),
+            None,
+        )
+        if abi is None:
+            raise ValueError("Four byte selector does not match the ABI for this contract")
+
+        function_sig = build_function_signature(abi)
+
+        types_list = get_type_strings(abi["inputs"])
+        result = eth_abi.decode_abi(types_list, calldata[4:])
+        input_args = format_input(abi, result)
+
+        return function_sig, input_args
+
 
 class _DeployedContractBase(_ContractBase):
     """Methods for interacting with a deployed contract.
@@ -712,14 +788,29 @@ class Contract(_DeployedContractBase):
                 BrownieCompilerWarning,
             )
 
-        if as_proxy_for is None and data["result"][0].get("Implementation"):
-            try:
-                # many proxy patterns use an `implementation()` function, so first we
-                # try to determine the implementation address without trusting etherscan
-                contract = cls.from_abi(name, address, abi)
-                as_proxy_for = contract.implementation()
-            except Exception:
-                as_proxy_for = _resolve_address(data["result"][0]["Implementation"])
+        if as_proxy_for is None:
+            # always check for an EIP1967 proxy - https://eips.ethereum.org/EIPS/eip-1967
+            implementation_eip1967 = web3.eth.getStorageAt(
+                address, int(web3.keccak(text="eip1967.proxy.implementation").hex(), 16) - 1
+            )
+            # always check for an EIP1822 proxy - https://eips.ethereum.org/EIPS/eip-1822
+            implementation_eip1822 = web3.eth.getStorageAt(address, web3.keccak(text="PROXIABLE"))
+            if int(implementation_eip1967.hex(), 16):
+                as_proxy_for = _resolve_address(implementation_eip1967[12:])
+            elif int(implementation_eip1822.hex(), 16):
+                as_proxy_for = _resolve_address(implementation_eip1822[12:])
+            elif data["result"][0].get("Implementation"):
+                # for other proxy patterns, we only check if etherscan indicates
+                # the contract is a proxy. otherwise we could have a false positive
+                # if there is an `implementation` method on a regular contract.
+                try:
+                    # first try to call `implementation` per EIP897
+                    # https://eips.ethereum.org/EIPS/eip-897
+                    contract = cls.from_abi(name, address, abi)
+                    as_proxy_for = contract.implementation.call()
+                except Exception:
+                    # if that fails, fall back to the address provided by etherscan
+                    as_proxy_for = _resolve_address(data["result"][0]["Implementation"])
 
         if as_proxy_for == address:
             as_proxy_for = None
