@@ -74,7 +74,8 @@ class TxHistory(metaclass=_Singleton):
         self._list = [i for i in self._list if i.block_number <= height]
 
     def _add_tx(self, tx: TransactionReceipt) -> None:
-        self._list.append(tx)
+        if tx not in self._list:
+            self._list.append(tx)
 
     def clear(self) -> None:
         self._list.clear()
@@ -110,6 +111,31 @@ class TxHistory(metaclass=_Singleton):
             return result
         return [i for i in result if key(i)]
 
+    def wait(self, key: Optional[Callable] = None, **kwargs: Optional[Any]) -> None:
+        """
+        Wait for pending transactions to confirm.
+
+        This method iterates over a list of transactions generated by `TxHistory.filter`,
+        waiting until each transaction has confirmed. If no arguments are given, all
+        transactions within the container are used.
+
+        Arguments
+        ---------
+        key : Callable, optional
+            An optional function to filter with. It should expect one agument and return
+            True or False.
+
+        Keyword Arguments
+        -----------------
+        **kwargs : Any
+            Names and expected values for TransactionReceipt attributes.
+        """
+        while True:
+            pending = next(iter(self.filter(key, status=-1, **kwargs)), None)
+            if pending is None:
+                return
+            pending._confirmed.wait()
+
     def from_sender(self, account: str) -> List:
         """Returns a list of transactions where the sender is account"""
         return [i for i in self._list if i.sender == account]
