@@ -2,6 +2,7 @@
 
 import builtins
 import json
+import re
 import sys
 import warnings
 from pathlib import Path
@@ -47,12 +48,27 @@ def revert_deprecation(revert_msg=None):
 
 
 class RevertContextManager:
-    def __init__(self, revert_msg=None):
+    def __init__(
+        self, revert_msg=None, dev_revert_msg=None, revert_pattern=None, dev_revert_pattern=None
+    ):
+        if revert_msg is not None and revert_pattern is not None:
+            raise ValueError("Can only use one of`revert_msg` and `revert_pattern`")
+        if dev_revert_msg is not None and dev_revert_pattern is not None:
+            raise ValueError("Can only use one of `dev_revert_msg` and `dev_revert_pattern`")
+
+        if revert_pattern:
+            re.compile(revert_pattern)
+        if dev_revert_pattern:
+            re.compile(dev_revert_pattern)
+
         self.revert_msg = revert_msg
+        self.dev_revert_msg = dev_revert_msg
+        self.revert_pattern = revert_pattern
+        self.dev_revert_pattern = dev_revert_pattern
         self.always_transact = CONFIG.argv["always_transact"]
 
-        if revert_msg is not None and revert_msg.startswith("dev:"):
-            # run calls as transactins when catching a dev revert string
+        if revert_msg is not None and (revert_msg.startswith("dev:") or dev_revert_msg):
+            # run calls as transactinos when catching a dev revert string
             CONFIG.argv["always_transact"] = True
 
     def __enter__(self):
@@ -67,15 +83,29 @@ class RevertContextManager:
         if exc_type is not VirtualMachineError:
             raise
 
-        if self.revert_msg is None or self.revert_msg == exc_value.revert_msg:
-            return True
+        if self.dev_revert_msg or self.dev_revert_pattern:
+            actual = exc_value.dev_revert_msg
+            if (
+                actual is None
+                or (self.dev_revert_pattern and not re.fullmatch(self.dev_revert_pattern, actual))
+                or (self.dev_revert_msg and self.dev_revert_msg != actual)
+            ):
+                raise AssertionError(
+                    f"Unexpected dev revert string '{actual}'\n{exc_value.source}"
+                ) from None
 
-        if exc_value.revert_msg is None:
-            raise AssertionError("Transaction reverted, but no revert string was given") from None
+        if self.revert_msg or self.revert_pattern:
+            actual = exc_value.revert_msg
+            if (
+                actual is None
+                or (self.revert_pattern and not re.fullmatch(self.revert_pattern, actual))
+                or (self.revert_msg and self.revert_msg != actual)
+            ):
+                raise AssertionError(
+                    f"Unexpected revert string '{actual}'\n{exc_value.source}"
+                ) from None
 
-        raise AssertionError(
-            f"Unexpected revert string '{exc_value.revert_msg}'\n{exc_value.source}"
-        ) from None
+        return True
 
 
 class PytestPrinter:
@@ -152,8 +182,7 @@ class PytestBrownieRunner(PytestBrownieBase):
         items in-place.
 
         Determines which modules are isolated, and skips tests based on
-        the `--update` and `--stateful` flags as well as the `skip_coverage`
-        fixture.
+        the `--update` and `--stateful` flags.
 
         Arguments
         ---------
@@ -166,10 +195,6 @@ class PytestBrownieRunner(PytestBrownieBase):
 
         tests = {}
         for i in items:
-            # apply skip_coverage
-            if "skip_coverage" in i.fixturenames and CONFIG.argv["coverage"]:
-                i.add_marker("skip")
-
             # apply --stateful flag
             if stateful is not None:
                 if stateful == "true" and "state_machine" not in i.fixturenames:
@@ -258,6 +283,32 @@ class PytestBrownieRunner(PytestBrownieBase):
                 # all tests are initially marked as skipped
                 self.results[path] = ["s"] * len(self.node_map[path])
 
+    def pytest_runtest_setup(self, item):
+        """
+        Called to perform the setup phase for a test item.
+
+        * The `require_network` marker is applied.
+
+        Arguments
+        ---------
+        item : _pytest.nodes.Item
+            Test item for which setup is performed.
+        """
+        # `require_network` marker logic
+        marker = next(item.iter_markers(name="require_network"), None)
+        if marker is not None:
+            if not len(marker.args):
+                raise ValueError("`require_network` marker must include a network name")
+            if brownie.network.show_active() not in marker.args:
+                pytest.skip("Active network does not match `require_network` marker")
+                return
+
+        if CONFIG.argv["coverage"] and (
+            next(item.iter_markers(name="skip_coverage"), None)
+            or "skip_coverage" in item.fixturenames
+        ):
+            pytest.skip("`skip_coverage` marker and coverage is active")
+
     def pytest_runtest_logreport(self, report):
         """
         Process a test setup/call/teardown report relating to the respective phase
@@ -315,6 +366,27 @@ class PytestBrownieRunner(PytestBrownieBase):
             "results": "".join(self.results[path]),
         }
 
+    @pytest.hookimpl(hookwrapper=True)
+    def pytest_runtest_call(self, item):
+        """
+        Called to run the test for test item (the call phase).
+
+        * Handles logic for the `always_transact` marker.
+
+        Arguments
+        ---------
+        item : _pytest.nodes.Item
+            Test item for which setup is performed.
+        """
+        no_call_coverage = next(item.iter_markers(name="no_call_coverage"), None)
+        if no_call_coverage:
+            CONFIG.argv["always_transact"] = False
+
+        yield
+
+        if no_call_coverage:
+            CONFIG.argv["always_transact"] = CONFIG.argv["coverage"]
+
     def pytest_report_teststatus(self, report):
         """
         Return result-category, shortletter and verbose word for status reporting.
@@ -349,13 +421,18 @@ class PytestBrownieRunner(PytestBrownieBase):
             Result/Exception info for the failed test.
         """
         if self.config.getoption("interactive") and report.failed:
+            location = self._path(report.location[0])
+            if location not in self.node_map:
+                # if the exception happened prior to collection it is likely a
+                # SyntaxError and we cannot open an interactive debugger
+                return
+
             capman = self.config.pluginmanager.get_plugin("capturemanager")
             if capman:
                 capman.suspend_global_capture(in_=True)
 
             tw = TerminalWriter()
             report.longrepr.toterminal(tw)
-            location = self._path(report.location[0])
 
             # find last traceback frame within the active test
             excinfo = call.excinfo
